/**
 * @file    libsedml-config.h
 * @brief   Decides whether to include Unix or Windows configuration variables.
 *
 * <!--------------------------------------------------------------------------
 *
 * This file is part of libSEDML.  Please visit http://sed-ml.org for more
 * information about SED-ML. The latest version of libSEDML can be found on
 * github: https://github.com/fbergmann/libSEDML/
 *
 *
 * Copyright (c) 2013-2014, Frank T. Bergmann
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * ---------------------------------------------------------------------- -->
 *
 * Some explanations about this file are warranted.  This file includes
 * one of the following (depending on operating system and compiler):
 *
 * - <tt>libsedml-config-unix.h</tt>
 * - <tt>libsedml-config-win.h</tt>
 *
 * On Linux, MacOS X, Cygwin, etc., <tt>libsedml-config-unix.h</tt> and
 * <tt>libsedml-package.h</tt> are generated from
 * <tt>libsedml-config-unix.h.in</tt> and <tt>libsedml-package.h.in</tt>,
 * respectively, by the @c configure script at the top level of the libSEDML
 * distribution.
 *
 * On Windows, we cannot rely on <tt>libsedml-config-win.h</tt> being
 * generated by @c configure, since most developers will not be able to run
 * @c configure in that environment.  Instead, both
 * <tt>libsedml-config-win.h</tt> and <tt>libsedml-package.h</tt> (which see)
 * are stored in the source repository and must be updated by the libSEDML
 * developers as necessary.  The file <tt>libsedml-config-win.h</tt> should
 * rarely, if ever, need to be updated, while <tt>libsedml-package.h</tt>
 * should require minor updates prior to each libsedml release.  This is
 * admittedly not an ideal and fool-proof arrangement; however, at this
 * time it is the best we have been able to find under the circumstances.
 *
 * Finally, <tt>libsedml-config.h</tt>, <tt>libsedml-package.h</tt>,
 * <tt>libsedml-config-unix.h</tt>, and (for consistency)
 * <tt>libsedml-config-win.h</tt> are all installed by @c "make install".
 */

#ifndef LIBSEDML_CONFIG_H
#define LIBSEDML_CONFIG_H 1

#include <sedml/common/libsedml-namespace.h>

#include <sedml/common/libsedml-config-common.h>

#include <sedml/common/libsedml-version.h>


#endif  /* LIBSEDML_CONFIG_H */

